Visions
=======

|JossPaper|
|PyPiDownloadsBadge|
|PyPiDownloadsMonthlyBadge|
|PyPiVersionBadge|
|PythonBadge|
|BinderBadge|

..

    *And these visions of data types, they kept us up past the dawn.*

..

`Visions` provides an extensible suite of tools to support common data analysis operations including

* type inference on unknown data
* casting data types
* automated data summarization

Documentation
-------------

Full documentation can be found `here <https://dylan-profiler.github.io/visions/>`_.

Installation
------------

You can install `visions` via pip:

.. code-block:: console

    pip install visions

Alternatives and more details can be found in the `documentation <https://dylan-profiler.github.io/visions/visions/getting_started/installation.html>`_.

Contributing and support
------------------------
Contributions to `visions` are welcome.
For more information, please visit the `Community contributions page <https://dylan-profiler.github.io/visions/visions/creator/contributing>`_.
The `the Github issues tracker <https://github.com/dylan-profiler/visions/issues/new/choose>`_ is used for reporting bugs, feature requests and support questions.

Acknowledgements
----------------

This package is part of the `dylan-profiler <https://github.com/dylan-profiler>`_ project.
The package is core component of `pandas-profiling <https://github.com/pandas-profiling/pandas-profiling>`_.
More information can be found `here <https://dylan-profiler.github.io/visions/visions/about.html>`__.
This work was partially supported by `SIDN Fonds <https://www.sidnfonds.nl/projecten/dylan-data-analysis-leveraging-automatisation>`_.


.. image:: https://github.com/dylan-profiler/visions/raw/master/SIDNfonds.png

.. |BinderBadge| image:: https://mybinder.org/badge_logo.svg
    :target: https://mybinder.org/v2/gh/dylan-profiler/visions/master
 
.. |JossPaper| image:: https://joss.theoj.org/papers/10.21105/joss.02145/status.svg
    :target: https://doi.org/10.21105/joss.02145
    
.. |PythonBadge| image:: https://img.shields.io/pypi/pyversions/visions
    :target: https://pypi.org/project/visions/
    
.. |PyPiDownloadsBadge| image:: https://pepy.tech/badge/visions
    :target: https://pypi.org/project/visions/
    
.. |PyPiDownloadsMonthlyBadge| image:: https://pepy.tech/badge/visions/month
    :target: https://pypi.org/project/visions/
    
.. |PyPiVersionBadge| image:: https://badge.fury.io/py/visions.svg
    :target: https://pypi.org/project/visions/
